==> xmlroff_0.5.1.orig.tar.gz: xmlroff-0.5.1/libfo/property/fo-property-padding-start.h <==
/* Fo
 * fo-property-padding-start.h: 'padding-start' property
 *
 * Copyright (C) 2001 Sun Microsystems
 * Copyright (C) 2007 Menteith Consulting Ltd
 *
 * See COPYING for the status of this software.
 */

#ifndef __FO_PROPERTY_PADDING_START_H__
#define __FO_PROPERTY_PADDING_START_H__

#include <libfo/fo-utils.h>
#include <property/fo-property.h>

G_BEGIN_DECLS

/* padding-start */
/* <padding-width> | <length-conditional> | inherit */
/* Initial value: 0pt */
/* NO ENUMERATED VALUE */

#define FO_TYPE_PROPERTY_PADDING_START              (fo_property_padding_start_get_type ())
#define FO_PROPERTY_PADDING_START(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStart))
#define FO_PROPERTY_PADDING_START_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStartClass))
#define FO_IS_PROPERTY_PADDING_START(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), FO_TYPE_PROPERTY_PADDING_START))
#define FO_IS_PROPERTY_PADDING_START_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), FO_TYPE_PROPERTY_PADDING_START))
#define FO_PROPERTY_PADDING_START_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStartClass))


typedef struct _FoPropertyPaddingStart      FoPropertyPaddingStart;
typedef struct _FoPropertyPaddingStartClass FoPropertyPaddingStartClass;

GType       fo_property_padding_start_get_type    (void) G_GNUC_CONST;
FoProperty* fo_property_padding_start_new         (void);
FoProperty* fo_property_padding_start_get_initial (void);

G_END_DECLS

#endif /* !__FO_PROPERTY_PADDING_START_H__ */

==> xmlroff_0.6.2.orig.tar.gz: xmlroff-0.6.2/libfo/property/fo-property-padding-start.h <==
/* Fo
 * fo-property-padding-start.h: 'padding-start' property
 *
 * Copyright (C) 2001 Sun Microsystems
 * Copyright (C) 2007-2008 Menteith Consulting Ltd
 *
 * See COPYING for the status of this software.
 */

#ifndef __FO_PROPERTY_PADDING_START_H__
#define __FO_PROPERTY_PADDING_START_H__

#include <libfo/fo-utils.h>
#include <libfo/property/fo-property.h>

G_BEGIN_DECLS

/* padding-start */
/* <padding-width> | <length-conditional> | inherit */
/* Initial value: 0pt */
/* NO ENUMERATED VALUE */

#define FO_TYPE_PROPERTY_PADDING_START              (fo_property_padding_start_get_type ())
#define FO_PROPERTY_PADDING_START(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStart))
#define FO_PROPERTY_PADDING_START_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStartClass))
#define FO_IS_PROPERTY_PADDING_START(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), FO_TYPE_PROPERTY_PADDING_START))
#define FO_IS_PROPERTY_PADDING_START_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), FO_TYPE_PROPERTY_PADDING_START))
#define FO_PROPERTY_PADDING_START_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), FO_TYPE_PROPERTY_PADDING_START, FoPropertyPaddingStartClass))


typedef struct _FoPropertyPaddingStart      FoPropertyPaddingStart;
typedef struct _FoPropertyPaddingStartClass FoPropertyPaddingStartClass;

GType       fo_property_padding_start_get_type    (void) G_GNUC_CONST;
FoProperty* fo_property_padding_start_new         (void);
FoProperty* fo_property_padding_start_get_initial (void);

G_END_DECLS

#endif /* !__FO_PROPERTY_PADDING_START_H__ */
